@@ -359,7 +359,18 @@ JAGS_add_priors           <- function(syntax, prior_list){
   syntax_end      <- substr(syntax, opening_bracket + 1, nchar(syntax))
 
   # create the priors relevant syntax
+  syntax_priors <- .JAGS_add_priors.fun(prior_list)
+
+  # merge everything back together
+  syntax <- paste0(syntax_start, "\n", syntax_priors, "\n", syntax_end)
+
+  return(syntax)
+}
+
+.JAGS_add_priors.fun       <- function(prior_list){
+
   syntax_priors <- ""
+
   for(i in seq_along(prior_list)){
 
     if(is.prior.weightfunction(prior_list[[i]])){
@@ -370,6 +381,10 @@ JAGS_add_priors           <- function(syntax, prior_list){
 
       syntax_priors <- paste(syntax_priors, .JAGS_prior.PP(prior_list[[i]]))
 
+    }else if(is.prior.spike_and_slab(prior_list[[i]])){
+
+      syntax_priors <- paste(syntax_priors, .JAGS_prior.spike_and_slab(prior_list[[i]], names(prior_list)[i]))
+
     }else if(is.prior.factor(prior_list[[i]])){
 
       syntax_priors <- paste(syntax_priors, .JAGS_prior.factor(prior_list[[i]], names(prior_list)[i]))
@@ -385,13 +400,8 @@ JAGS_add_priors           <- function(syntax, prior_list){
     }
   }
 
-  # merge everything back together
-  syntax <- paste0(syntax_start, "\n", syntax_priors, "\n", syntax_end)
-
-  return(syntax)
+  return(syntax_priors)
 }
-
-
 .JAGS_prior.simple         <- function(prior, parameter_name){
 
   .check_prior(prior)
@@ -410,6 +420,7 @@ JAGS_add_priors           <- function(syntax, prior_list){
     "invgamma"  = paste0("inv_",parameter_name," ~ dgamma(",prior$parameter[["shape"]],",",prior$parameter[["scale"]],")"),
     "exp"       = paste0(parameter_name," ~ dexp(",prior$parameter[["rate"]],")"),
     "beta"      = paste0(parameter_name," ~ dbeta(",prior$parameter[["alpha"]],",",prior$parameter[["beta"]],")"),
+    "bernoulli" = paste0(parameter_name," ~ dbern(",prior$parameter[["probability"]],")"),
     "uniform"   = paste0(parameter_name," ~ dunif(",prior$parameter[["a"]],",",prior$parameter[["b"]],")")
   )
 
@@ -583,7 +594,33 @@ JAGS_add_priors           <- function(syntax, prior_list){
 
   return(syntax)
 }
+.JAGS_prior.spike_and_slab <- function(prior, parameter_name){
 
+  .check_prior(prior)
+  if(!is.prior.spike_and_slab(prior))
+    stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
+
+  if(is.prior.PET(prior[["variable"]]) | is.prior.PEESE(prior[["variable"]]) | is.prior.weightfunction(prior[["variable"]]))
+    stop("Spike and slab functionality is not implemented for publication bias prior distributions.")
+  if(is.prior.spike_and_slab(prior[["variable"]]))
+     stop("Spike and slab prior distribution cannot be nested inside of a spike and slab prior distribution.")
+
+
+  prior_variable_list  <- prior["variable"]
+  prior_inclusion_list <- prior["inclusion"]
+  names(prior_variable_list)  <- paste0(parameter_name, "_variable")
+  names(prior_inclusion_list) <- paste0(parameter_name, "_inclusion")
+
+  syntax <- paste0(
+    .JAGS_add_priors.fun(prior_variable_list),
+    .JAGS_add_priors.fun(prior_inclusion_list),
+    parameter_name, "_indicator ~ dbern(",   paste0(parameter_name, "_inclusion"), ")\n",
+    parameter_name, " = ",  parameter_name, "_variable * ", parameter_name, "_indicator\n"
+  )
+
+  return(syntax)
+}
 
 .check_JAGS_syntax <- function(syntax){
 
@@ -638,36 +675,7 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
   inits <- vector("list", chains)
   for(j in 1:chains){
 
-    temp_inits <- list()
-
-    for(i in seq_along(prior_list)){
-
-      if(is.prior.point(prior_list[[i]])){
-
-        next
-
-      }else if(is.prior.weightfunction(prior_list[[i]])){
-
-        temp_inits <- c(temp_inits, .JAGS_init.weightfunction(prior_list[[i]]))
-
-      }else if(is.prior.PET(prior_list[[i]]) | is.prior.PEESE(prior_list[[i]])){
-
-        temp_inits <- c(temp_inits, .JAGS_init.PP(prior_list[[i]]))
-
-      }else if(is.prior.factor(prior_list[[i]])){
-
-        temp_inits <- c(temp_inits, .JAGS_init.factor(prior_list[[i]], names(prior_list)[i]))
-
-      }else if(is.prior.vector(prior_list[[i]])){
-
-        temp_inits <- c(temp_inits, .JAGS_init.vector(prior_list[[i]], names(prior_list)[i]))
-
-      }else if(is.prior.simple(prior_list[[i]])){
-
-        temp_inits <- c(temp_inits, .JAGS_init.simple(prior_list[[i]], names(prior_list)[i]))
-
-      }
-    }
+    temp_inits <- .JAGS_get_inits.fun(prior_list)
 
     temp_inits[[".RNG.seed"]] <- seed + j
     temp_inits[[".RNG.name"]] <- "base::Super-Duper"
@@ -678,12 +686,51 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
   return(inits)
 }
 
+.JAGS_get_inits.fun        <- function(prior_list){
 
+  temp_inits <- list()
+
+  for(i in seq_along(prior_list)){
+
+    if(is.prior.point(prior_list[[i]])){
+
+      next
+
+    }else if(is.prior.weightfunction(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.weightfunction(prior_list[[i]]))
+
+    }else if(is.prior.PET(prior_list[[i]]) | is.prior.PEESE(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.PP(prior_list[[i]]))
+
+    }else if(is.prior.spike_and_slab(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.spike_and_slab(prior_list[[i]], names(prior_list)[i]))
+
+    }else if(is.prior.factor(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.factor(prior_list[[i]], names(prior_list)[i]))
+
+    }else if(is.prior.vector(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.vector(prior_list[[i]], names(prior_list)[i]))
+
+    }else if(is.prior.simple(prior_list[[i]])){
+
+      temp_inits <- c(temp_inits, .JAGS_init.simple(prior_list[[i]], names(prior_list)[i]))
+
+    }
+  }
+
+  return(temp_inits)
+}
 .JAGS_init.simple          <- function(prior, parameter_name){
 
   .check_prior(prior)
   if(!is.prior.simple(prior))
     stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
 
   if(prior[["distribution"]] == "point"){
 
@@ -714,6 +761,7 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
   .check_prior(prior)
   if(!is.prior.vector(prior))
     stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
 
   if(prior[["distribution"]] == "point"){
 
@@ -799,6 +847,23 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
 
   return(init)
 }
+.JAGS_init.spike_and_slab  <- function(prior, parameter_name){
+
+  .check_prior(prior)
+  if(!is.prior.spike_and_slab(prior))
+    stop("improper prior provided")
+
+  prior_variable        <- prior["variable"]
+  names(prior_variable) <- paste0(parameter_name, "_variable")
+  init <- .JAGS_get_inits.fun(prior_variable)
+
+  if(!is.prior.point(prior[["inclusion"]])){
+    init[[paste0(parameter_name, "_inclusion")]] <- rng(prior[["inclusion"]], 1)
+  }
+
+
+  return(init)
+}
 
 
 #' @title Create list of monitored parameters for 'JAGS' model
@@ -836,6 +901,10 @@ JAGS_to_monitor             <- function(prior_list){
 
       monitor <- c(monitor, .JAGS_monitor.PP(prior_list[[i]]))
 
+    }else if(is.prior.spike_and_slab(prior_list[[i]])){
+
+      monitor <- c(monitor, .JAGS_monitor.spike_and_slab(prior_list[[i]], names(prior_list)[i]))
+
     }else if(is.prior.factor(prior_list[[i]])){
 
       monitor <- c(monitor, .JAGS_monitor.factor(prior_list[[i]], names(prior_list)[i]))
@@ -860,8 +929,7 @@ JAGS_to_monitor             <- function(prior_list){
   .check_prior(prior)
   if(!(is.prior.simple(prior) | is.prior.vector(prior) | is.prior.factor(prior)))
     stop("improper prior provided")
-  if(!is.character(parameter_name) | length(parameter_name) != 1)
-    stop("'parameter_name' must be a character vector of length 1.")
+  check_char(parameter_name, "parameter_name")
 
   if(prior[["distribution"]] == "invgamma"){
     monitor <- c(parameter_name, paste0("inv_", parameter_name))
@@ -912,7 +980,27 @@ JAGS_to_monitor             <- function(prior_list){
 
   return(monitor)
 }
+.JAGS_monitor.spike_and_slab <- function(prior, parameter_name){
 
+  .check_prior(prior)
+  if(!is.prior.spike_and_slab(prior))
+    stop("improper prior provided")
+  check_char(parameter_name, "parameter_name")
+
+  prior_variable  <- prior["variable"]
+  prior_inclusion <- prior["inclusion"]
+  names(prior_variable)  <- paste0(parameter_name, "_variable")
+  names(prior_inclusion) <- paste0(parameter_name, "_inclusion")
+
+  monitor <- c(
+    parameter_name,
+    JAGS_to_monitor(prior_variable),
+    JAGS_to_monitor(prior_inclusion),
+    paste0(parameter_name, "_indicator")
+  )
+
+  return(monitor)
+}
 
 #' @title Check and list 'JAGS' fitting settings
 #'
